from tkinter import *
from VIStk.Objects._WindowGeometry import WindowGeometry
from VIStk.Objects._Window import Window

class Root(Tk, Window):
    """A wrapper for the Tk class with VIS attributes"""
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)
        self.WindowGeometry = WindowGeometry(self)

    def fullscreen(self):
        """Makes the window fullscreen"""


from VIStk.Widgets._QuestionWindow import QuestionWindow
from tkinter import *

class WarningWindow(QuestionWindow):
    def __init__(self, warning:str|list[str], parent:Toplevel|Tk, *args, **kwargs):
        super().__init__(question=warning, parent=parent, answer="u", ycommand=None, *args, **kwargs)
        self.screen_elements[0]["anchor"] = "center"
        self.focus_force()
        self.transient(parent)
        self.grab_set()
        parent.wait_window(self)